==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/record/vo/RecordContrastanalysisdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 对比分析变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordContrastanalysisdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String code; // 清单编码
    private java.lang.String name; // 工程名称或费用名称
    private java.math.BigDecimal biddingStage; // 投标阶段
    private java.math.BigDecimal quataDesignTotal; // 限额设计阶段
    private java.math.BigDecimal designBugetEstimate; // 设计概算阶段
    private java.math.BigDecimal constructionBugetEstimate; // 施工图预算阶段
    private java.math.BigDecimal tenderListTotal; // 投标清单合价
    private java.math.BigDecimal tenderListPrice; // 投标清单单价
    private java.math.BigDecimal quotaDesignBudgetTotal; // 限额设计预算合价
    private java.math.BigDecimal quotaDesignBudgetPrice; // 限额设计预算单价
    private java.util.Date designBugetEstimateTotal; // 设计概算合价
    private java.math.BigDecimal designBugetEstimatePrice; // 设计概算单价
    private java.math.BigDecimal constructionBugetEstimateTotal; // 施工图预算合价
    private java.math.BigDecimal constructionBugetEstimatePrice; // 施工图预算单价
    private java.lang.String memo; // 备注
    private java.lang.String tid; // 表格行id
    private java.lang.String tpid; // 表格行父id
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 清单编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 工程名称或费用名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 投标阶段
     */
    public java.math.BigDecimal getBiddingStage() {
        return biddingStage;
    }

    /**
     * 投标阶段
     */
    public void setBiddingStage(java.math.BigDecimal biddingStage) {
        this.biddingStage = biddingStage;
    }
    /**
     * 限额设计阶段
     */
    public java.math.BigDecimal getQuataDesignTotal() {
        return quataDesignTotal;
    }

    /**
     * 限额设计阶段
     */
    public void setQuataDesignTotal(java.math.BigDecimal quataDesignTotal) {
        this.quataDesignTotal = quataDesignTotal;
    }
    /**
     * 设计概算阶段
     */
    public java.math.BigDecimal getDesignBugetEstimate() {
        return designBugetEstimate;
    }

    /**
     * 设计概算阶段
     */
    public void setDesignBugetEstimate(java.math.BigDecimal designBugetEstimate) {
        this.designBugetEstimate = designBugetEstimate;
    }
    /**
     * 施工图预算阶段
     */
    public java.math.BigDecimal getConstructionBugetEstimate() {
        return constructionBugetEstimate;
    }

    /**
     * 施工图预算阶段
     */
    public void setConstructionBugetEstimate(java.math.BigDecimal constructionBugetEstimate) {
        this.constructionBugetEstimate = constructionBugetEstimate;
    }
    /**
     * 投标清单合价
     */
    public java.math.BigDecimal getTenderListTotal() {
        return tenderListTotal;
    }

    /**
     * 投标清单合价
     */
    public void setTenderListTotal(java.math.BigDecimal tenderListTotal) {
        this.tenderListTotal = tenderListTotal;
    }
    /**
     * 投标清单单价
     */
    public java.math.BigDecimal getTenderListPrice() {
        return tenderListPrice;
    }

    /**
     * 投标清单单价
     */
    public void setTenderListPrice(java.math.BigDecimal tenderListPrice) {
        this.tenderListPrice = tenderListPrice;
    }
    /**
     * 限额设计预算合价
     */
    public java.math.BigDecimal getQuotaDesignBudgetTotal() {
        return quotaDesignBudgetTotal;
    }

    /**
     * 限额设计预算合价
     */
    public void setQuotaDesignBudgetTotal(java.math.BigDecimal quotaDesignBudgetTotal) {
        this.quotaDesignBudgetTotal = quotaDesignBudgetTotal;
    }
    /**
     * 限额设计预算单价
     */
    public java.math.BigDecimal getQuotaDesignBudgetPrice() {
        return quotaDesignBudgetPrice;
    }

    /**
     * 限额设计预算单价
     */
    public void setQuotaDesignBudgetPrice(java.math.BigDecimal quotaDesignBudgetPrice) {
        this.quotaDesignBudgetPrice = quotaDesignBudgetPrice;
    }
    /**
     * 设计概算合价
     */
    public java.util.Date getDesignBugetEstimateTotal() {
        return designBugetEstimateTotal;
    }

    /**
     * 设计概算合价
     */
    public void setDesignBugetEstimateTotal(java.util.Date designBugetEstimateTotal) {
        this.designBugetEstimateTotal = designBugetEstimateTotal;
    }
    /**
     * 设计概算单价
     */
    public java.math.BigDecimal getDesignBugetEstimatePrice() {
        return designBugetEstimatePrice;
    }

    /**
     * 设计概算单价
     */
    public void setDesignBugetEstimatePrice(java.math.BigDecimal designBugetEstimatePrice) {
        this.designBugetEstimatePrice = designBugetEstimatePrice;
    }
    /**
     * 施工图预算合价
     */
    public java.math.BigDecimal getConstructionBugetEstimateTotal() {
        return constructionBugetEstimateTotal;
    }

    /**
     * 施工图预算合价
     */
    public void setConstructionBugetEstimateTotal(java.math.BigDecimal constructionBugetEstimateTotal) {
        this.constructionBugetEstimateTotal = constructionBugetEstimateTotal;
    }
    /**
     * 施工图预算单价
     */
    public java.math.BigDecimal getConstructionBugetEstimatePrice() {
        return constructionBugetEstimatePrice;
    }

    /**
     * 施工图预算单价
     */
    public void setConstructionBugetEstimatePrice(java.math.BigDecimal constructionBugetEstimatePrice) {
        this.constructionBugetEstimatePrice = constructionBugetEstimatePrice;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 表格行id
     */
    public java.lang.String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(java.lang.String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public java.lang.String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(java.lang.String tpid) {
        this.tpid = tpid;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220408.085606-74-sources.jar: com/ejianc/business/record/vo/RecordContrastanalysisdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 对比分析变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordContrastanalysisdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Long originalId; // 原始单据id（对比分析表子表）
    private java.lang.String sort; // 序号
    private java.lang.String code; // 清单编码
    private java.lang.String name; // 工程名称或费用名称
    private java.math.BigDecimal biddingStage; // 投标阶段
    private java.math.BigDecimal quataDesignTotal; // 限额设计阶段
    private java.math.BigDecimal designBugetEstimate; // 设计概算阶段
    private java.math.BigDecimal constructionBugetEstimate; // 施工图预算阶段
    private java.math.BigDecimal tenderListTotal; // 投标清单合价
    private java.math.BigDecimal tenderListPrice; // 投标清单单价
    private java.math.BigDecimal quotaDesignBudgetTotal; // 限额设计预算合价
    private java.math.BigDecimal quotaDesignBudgetPrice; // 限额设计预算单价
    private java.math.BigDecimal designBugetEstimateTotal; // 设计概算合价
    private java.math.BigDecimal designBugetEstimatePrice; // 设计概算单价
    private java.math.BigDecimal constructionBugetEstimateTotal; // 施工图预算合价
    private java.math.BigDecimal constructionBugetEstimatePrice; // 施工图预算单价
    private java.lang.String memo; // 备注
    private java.lang.String tid; // 表格行id
    private java.lang.String tpid; // 表格行父id
    private String innercode; // 内码

    private List<RecordContrastanalysisdetailVO> children = new ArrayList<>();
    public List<RecordContrastanalysisdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<RecordContrastanalysisdetailVO> children) {
        this.children = children;
    }
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 清单编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 工程名称或费用名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 投标阶段
     */
    public java.math.BigDecimal getBiddingStage() {
        return biddingStage;
    }

    /**
     * 投标阶段
     */
    public void setBiddingStage(java.math.BigDecimal biddingStage) {
        this.biddingStage = biddingStage;
    }
    /**
     * 限额设计阶段
     */
    public java.math.BigDecimal getQuataDesignTotal() {
        return quataDesignTotal;
    }

    /**
     * 限额设计阶段
     */
    public void setQuataDesignTotal(java.math.BigDecimal quataDesignTotal) {
        this.quataDesignTotal = quataDesignTotal;
    }
    /**
     * 设计概算阶段
     */
    public java.math.BigDecimal getDesignBugetEstimate() {
        return designBugetEstimate;
    }

    /**
     * 设计概算阶段
     */
    public void setDesignBugetEstimate(java.math.BigDecimal designBugetEstimate) {
        this.designBugetEstimate = designBugetEstimate;
    }
    /**
     * 施工图预算阶段
     */
    public java.math.BigDecimal getConstructionBugetEstimate() {
        return constructionBugetEstimate;
    }

    /**
     * 施工图预算阶段
     */
    public void setConstructionBugetEstimate(java.math.BigDecimal constructionBugetEstimate) {
        this.constructionBugetEstimate = constructionBugetEstimate;
    }
    /**
     * 投标清单合价
     */
    public java.math.BigDecimal getTenderListTotal() {
        return tenderListTotal;
    }

    /**
     * 投标清单合价
     */
    public void setTenderListTotal(java.math.BigDecimal tenderListTotal) {
        this.tenderListTotal = tenderListTotal;
    }
    /**
     * 投标清单单价
     */
    public java.math.BigDecimal getTenderListPrice() {
        return tenderListPrice;
    }

    /**
     * 投标清单单价
     */
    public void setTenderListPrice(java.math.BigDecimal tenderListPrice) {
        this.tenderListPrice = tenderListPrice;
    }
    /**
     * 限额设计预算合价
     */
    public java.math.BigDecimal getQuotaDesignBudgetTotal() {
        return quotaDesignBudgetTotal;
    }

    /**
     * 限额设计预算合价
     */
    public void setQuotaDesignBudgetTotal(java.math.BigDecimal quotaDesignBudgetTotal) {
        this.quotaDesignBudgetTotal = quotaDesignBudgetTotal;
    }
    /**
     * 限额设计预算单价
     */
    public java.math.BigDecimal getQuotaDesignBudgetPrice() {
        return quotaDesignBudgetPrice;
    }

    /**
     * 限额设计预算单价
     */
    public void setQuotaDesignBudgetPrice(java.math.BigDecimal quotaDesignBudgetPrice) {
        this.quotaDesignBudgetPrice = quotaDesignBudgetPrice;
    }
    /**
     * 设计概算合价
     */
    public java.math.BigDecimal getDesignBugetEstimateTotal() {
        return designBugetEstimateTotal;
    }

    /**
     * 设计概算合价
     */
    public void setDesignBugetEstimateTotal(java.math.BigDecimal designBugetEstimateTotal) {
        this.designBugetEstimateTotal = designBugetEstimateTotal;
    }
    /**
     * 设计概算单价
     */
    public java.math.BigDecimal getDesignBugetEstimatePrice() {
        return designBugetEstimatePrice;
    }

    /**
     * 设计概算单价
     */
    public void setDesignBugetEstimatePrice(java.math.BigDecimal designBugetEstimatePrice) {
        this.designBugetEstimatePrice = designBugetEstimatePrice;
    }
    /**
     * 施工图预算合价
     */
    public java.math.BigDecimal getConstructionBugetEstimateTotal() {
        return constructionBugetEstimateTotal;
    }

    /**
     * 施工图预算合价
     */
    public void setConstructionBugetEstimateTotal(java.math.BigDecimal constructionBugetEstimateTotal) {
        this.constructionBugetEstimateTotal = constructionBugetEstimateTotal;
    }
    /**
     * 施工图预算单价
     */
    public java.math.BigDecimal getConstructionBugetEstimatePrice() {
        return constructionBugetEstimatePrice;
    }

    /**
     * 施工图预算单价
     */
    public void setConstructionBugetEstimatePrice(java.math.BigDecimal constructionBugetEstimatePrice) {
        this.constructionBugetEstimatePrice = constructionBugetEstimatePrice;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 表格行id
     */
    public java.lang.String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(java.lang.String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public java.lang.String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(java.lang.String tpid) {
        this.tpid = tpid;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}
